RemoteSource

Trait RemoteSource 

pub trait RemoteSource {
    // Required methods
    fn origin(&self) -> &Origin;
    fn fetch(&self, ids: &[RecordId]) -> Result<Bundle>;
}
Something that can fetch records published by another origin.

Required Methods

fn origin(&self) -> &Origin

fn fetch(&self, ids: &[RecordId]) -> Result<Bundle>

Fetch a bundle containing ids (and their histories). Implementations must treat the response as untrusted and pass it through crate::interchange::parse_bundle before use.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors